@@ -15,6 +15,7 @@ use List::Util qw/shuffle/;
 # use IPC::Cmd qw/can_run/;
 
 use Moose;
+use namespace::autoclean;
 extends 'HPC::Runner';
 with 'MooseX::SimpleConfig';
 
@@ -31,7 +32,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.42';
+our $VERSION = '2.43';
 
 =head1 SYNOPSIS
 
@@ -377,20 +378,10 @@ has 'use_gnuparallel' => (
 
 =head2 use_custom
 
-Use a custom command
+Supply your own command instead of mcerunner/threadsrunner/etc
 
 =cut
 
-has 'use_custom' => (
-    is => 'rw',
-    isa => 'Bool',
-    default => 0,
-    required => 0,
-    documentation => q{Use custom command to run jobs},
-    predicate => 'has_use_custom',
-    clearer => 'clear_use_custom',
-);
-
 has 'custom_command' => (
     is => 'rw',
     isa => 'Str',
@@ -499,19 +490,20 @@ Current command specified by infile
 
 =cut
 
-has 'cmd' => (
-    traits  => ['String', 'NoGetopt'],
-    is => 'rw',
-    isa => 'Str',
-    required => 0,
-    default => q{},
-    handles => {
-        add_cmd => 'append',
-        match_cmd => 'match',
-    },
-    clearer => 'clear_cmd',
-    predicate => 'has_cmd',
-);
+#has 'cmd' => (
+    #traits  => ['String', 'NoGetopt'],
+    #is => 'rw',
+    #isa => 'Str',
+    #required => 0,
+    ##default => q{},
+    #handles => {
+        #add_cmd => 'append',
+        #match_cmd => 'match',
+    #},
+    #builder => '_build_cmd',
+    #clearer => 'clear_cmd',
+    #predicate => 'has_cmd',
+#);
 
 =head2 batch
 
@@ -979,7 +971,7 @@ sub process_batch_command {
         $command = "cd ".getcwd()."\n";
         $command .= $self->custom_command." --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
     }
-    if($self->use_gnuparallel){
+    elsif($self->use_gnuparallel){
         $command = "cd ".getcwd()."\n";
         $command .= "cat ".$self->cmdfile." | parallelparser.pl | parallel --joblog ".$self->outdir."/main.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter."\n";
     }
